==> test-plugin-1.3-sources.jar: com/xebialabs/deployit/plugin/test/TestConfigurationItem.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.test;

import com.xebialabs.deployit.BaseConfigurationItem;
import com.xebialabs.deployit.ConfigurationItem;
import com.xebialabs.deployit.ConfigurationItemProperty;

@SuppressWarnings("serial")
@ConfigurationItem(description="A CI which is used for performance testing the Core")
public class TestConfigurationItem extends BaseConfigurationItem {
	
	@ConfigurationItemProperty(description = "Number of steps to generate")
	private int numberOfSteps;
	
	@ConfigurationItemProperty(description = "Amount of log generated in KBytes")
	private int amountOfKBLogFiles;
	
	@ConfigurationItemProperty(description = "Amount of time in seconds each step will wait before continuing")
	private int stepDelayTimeInMilliSeconds;
	
	public int getNumberOfSteps() {
		return numberOfSteps;
	}

	public void setNumberOfSteps(int numberOfSteps) {
		this.numberOfSteps = numberOfSteps;
	}

	public int getAmountOfKBLogFiles() {
		return amountOfKBLogFiles;
	}

	public void setAmountOfKBLogFiles(int amountOfKBLogFiles) {
		this.amountOfKBLogFiles = amountOfKBLogFiles;
	}

	public int getStepDelayTimeInMilliSeconds() {
		return stepDelayTimeInMilliSeconds;
	}

	public void setStepDelayTimeInMilliSeconds(int stepDelayTimeInSeconds) {
		this.stepDelayTimeInMilliSeconds = stepDelayTimeInSeconds;
	}

}

==> test-plugin-3.0.3-sources.jar: com/xebialabs/deployit/plugin/test/TestConfigurationItem.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.test;

import com.xebialabs.deployit.BaseConfigurationItem;
import com.xebialabs.deployit.ConfigurationItem;
import com.xebialabs.deployit.ConfigurationItemProperty;

@SuppressWarnings("serial")
@ConfigurationItem(description="A CI which is used for performance testing the Core")
public class TestConfigurationItem extends BaseConfigurationItem {
	
	@ConfigurationItemProperty(description = "Number of steps to generate")
	private int numberOfSteps;
	
	@ConfigurationItemProperty(description = "Amount of log generated in KBytes")
	private int amountOfKBLogFiles;
	
	@ConfigurationItemProperty(description = "Amount of time in milliseconds each step will wait before continuing")
	private int stepDelayTimeInMilliSeconds;
	
	public int getNumberOfSteps() {
		return numberOfSteps;
	}

	public void setNumberOfSteps(int numberOfSteps) {
		this.numberOfSteps = numberOfSteps;
	}

	public int getAmountOfKBLogFiles() {
		return amountOfKBLogFiles;
	}

	public void setAmountOfKBLogFiles(int amountOfKBLogFiles) {
		this.amountOfKBLogFiles = amountOfKBLogFiles;
	}

	public int getStepDelayTimeInMilliSeconds() {
		return stepDelayTimeInMilliSeconds;
	}

	public void setStepDelayTimeInMilliSeconds(int stepDelayTimeInSeconds) {
		this.stepDelayTimeInMilliSeconds = stepDelayTimeInSeconds;
	}

}
